package ru.volgait.ftp.client_server;

import ru.volgait.ftp.client_server.command.Command;
import ru.volgait.ftp.client_server.command.CommandName;
import ru.volgait.ftp.client_server.exception.WrongCommandException;

import java.io.*;
import java.net.Socket;
import java.net.UnknownHostException;
import java.util.Scanner;

public class Client {

    private String serverHostname;
    private int serverPort;

    public Client(String hostname, int port) {
        this.serverPort = port;
        this.serverHostname = hostname;
    }

    public static void main(String[] args) throws IOException {
        System.out.println("Client is started");

        if (args.length != 2) {
            System.err.println("Usage: java Client <host name> <port number>");
            System.exit(1);
        }

        String hostName = args[0];
        int portNumber = Integer.parseInt(args[1]);
        Client client = new Client(hostName, portNumber);
        client.start();
    }

    public void start() throws IOException {
        try (
                Socket serverSocket = new Socket(serverHostname, serverPort);
                DataInputStream dIn = new DataInputStream(serverSocket.getInputStream());
                DataOutputStream dOut = new DataOutputStream(serverSocket.getOutputStream());
        ) {
            Scanner systemIn = new Scanner(System.in);
            String serverOutput = null;
            String commandInput;
            while ( (commandInput = systemIn.nextLine()) != null || ((serverOutput = dIn.readUTF()) != null ))  {
                if (serverOutput != null) {
                    System.out.println("Server: " + serverOutput);
                    if ((CommandName.contains(serverOutput)) && (CommandName.valueOf(serverOutput) == CommandName.CLOSE_CONNECTION)) {
                        System.out.println("Server is closed connection");
                        break;
                    }
                }

                if (commandInput != null) {
                    System.out.println("Client: " + commandInput);
                    try {
                        Command command = new Command(commandInput);
                        dOut.writeUTF(command.toString());
                    } catch (WrongCommandException e) {
                        System.err.println("No such command");
                    }
                }
            }
        } catch (UnknownHostException e) {
            System.err.println("Unknown host " + serverHostname);
        } catch (IOException e) {
            System.err.println("Can't get connection to server");
            System.exit(1);
        }
    }
}
